/// <reference types="node" />
import { Server as HttpServer } from 'http';
import { RouteDefinition } from '@rxstack/kernel';
import { Injector } from 'injection-js';
import { Logger } from '@rxstack/logger';
/**
 * Base class for servers
 */
export declare abstract class AbstractServer {
    /**
     * Injector
     */
    protected injector: Injector;
    /**
     * Server engine
     */
    protected engine: any;
    /**
     * Hostname
     */
    protected host: string;
    /**
     * Port number server is running on
     */
    protected port: number;
    /**
     * Http Server
     */
    protected httpServer: HttpServer;
    /**
     * Sets injector
     *
     * @param {Injector} injector
     */
    setInjector(injector: Injector): void;
    /**
     * Gets injector
     *
     * @returns {Injector}
     */
    getInjector(): Injector;
    /**
     * Kicks off the server
     */
    start(routeDefinitions: RouteDefinition[]): Promise<void>;
    /**
     * Retrieve the base instance of Server
     * @returns {HttpServer}
     */
    getHttpServer(): HttpServer;
    /**
     * Retrieve underlying engine
     *
     * @returns {any}
     */
    getEngine(): any;
    /**
     * Kicks off the server using the specific underlying engine
     */
    startEngine(): Promise<void>;
    /**
     * Stops underlying engine
     *
     * @returns {Promise<void>}
     */
    stopEngine(): Promise<void>;
    /**
     * Get the host name (for logging)
     * @returns {string}
     */
    getHost(): string;
    /**
     * Logger
     *
     * @returns {Logger}
     */
    protected getLogger(): Logger;
    /**
     * Configures the server
     *
     * @param {RouteDefinition[]} routeDefinitions
     * @returns {Promise<void>}
     */
    protected abstract configure(routeDefinitions: RouteDefinition[]): Promise<void>;
}
