"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("@rxstack/logger");
/**
 * Base class for servers
 */
class AbstractServer {
    /**
     * Sets injector
     *
     * @param {Injector} injector
     */
    setInjector(injector) {
        this.injector = injector;
    }
    /**
     * Gets injector
     *
     * @returns {Injector}
     */
    getInjector() {
        return this.injector;
    }
    /**
     * Kicks off the server
     */
    start(routeDefinitions) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.configure(routeDefinitions);
            yield this.startEngine();
        });
    }
    /**
     * Retrieve the base instance of Server
     * @returns {HttpServer}
     */
    getHttpServer() {
        return this.httpServer;
    }
    /**
     * Retrieve underlying engine
     *
     * @returns {any}
     */
    getEngine() {
        return this.engine;
    }
    /**
     * Kicks off the server using the specific underlying engine
     */
    startEngine() {
        return __awaiter(this, void 0, void 0, function* () {
            this.getHttpServer()
                .listen(this.port, this.host, () => this.getLogger().debug(`Starting ${this.getHost()}`));
        });
    }
    /**
     * Stops underlying engine
     *
     * @returns {Promise<void>}
     */
    stopEngine() {
        return __awaiter(this, void 0, void 0, function* () {
            this.getHttpServer().close(() => this.getLogger().debug(`Stopping ${this.getHost()}`));
        });
    }
    /**
     * Get the host name (for logging)
     * @returns {string}
     */
    getHost() {
        return `http://${this.host}:${this.port}`;
    }
    /**
     * Logger
     *
     * @returns {Logger}
     */
    getLogger() {
        return this.getInjector().get(logger_1.Logger).source(this.constructor.name);
    }
}
exports.AbstractServer = AbstractServer;

//# sourceMappingURL=abstract-server.js.map
